A simple description of an exact range of keyspace, specified by a begin and end key. As with all FoundationDB APIs, begin is inclusive, end exclusive.
A simple description of an exact range of keyspace, specified by a begin and end key. As with all FoundationDB APIs, begin is inclusive, end exclusive.
(range begin end)Construct a new Range with an inclusive begin key and an exclusive end key.
Construct a new Range with an inclusive begin key and an exclusive end key.
(starts-with prefix)Returns a Range that describes all possible keys that are prefixed with a specified key.
Parameters: prefix - the key prefixing the range, must not be null Returns: the range of keys starting with prefix
Returns a Range that describes all possible keys that are prefixed with a specified key. Parameters: prefix - the key prefixing the range, must not be null Returns: the range of keys starting with prefix
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |